# CLoDSA

CLoDeSeAugmentor is an open-source image augmentation library for object classification, localization, detection and semantic segmentation. It supports a wide variety of augmentation techniques and allows the user to easily combine them. 


## Features

* Several augmentation techniques are provided.
* Augmentation techniques can be applied for object classification, localization, detection, and semantic segmentation.
* A Java wizard to configure the library.
* Several input modes for reading the datasets.
* Several output modes to generate the augmented dataset. 
* It is possible to easily add new augmentation techniques and apply them for object classification, localization, detection, and semantic segmentation. 


